import"./outputWidgets.df0b7764.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="9dac75c2-1708-4867-97d4-e1a664494e53",x._sentryDebugIdIdentifier="sentry-dbid-9dac75c2-1708-4867-97d4-e1a664494e53")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),d=()=>Math.random().toString(36).slice(2);export{d as r,r as u};
//# sourceMappingURL=uuid.29060192.js.map
