import"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e506c975-b042-422f-9291-d2f2110baeb5",e._sentryDebugIdIdentifier="sentry-dbid-e506c975-b042-422f-9291-d2f2110baeb5")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.b34e96a5.js.map
