import{S as p}from"./Sidebar.60765a93.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.5d2a3613.js";import{G as d,H as l,I as u}from"./icons.649962e7.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.df0b7764.js";import{a as w}from"./asyncComputed.46396f29.js";import"./router.7d542f8a.js";import{O as z}from"./organization.f7e77816.js";import"./index.be0d60a2.js";import{B as h}from"./BaseLayout.2f5857c5.js";import"./Tooltip.fe0b11a9.js";import"./logo.084e5d7c.js";import"./index.0830e379.js";import"./Title.d627f1f5.js";import"./index.317ac553.js";import"./index.ff998eb1.js";import"./index.8131d28d.js";import"./gateway.315bccd7.js";import"./activeRecord.af31c98a.js";import"./pubsub.82647744.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3b23b6e3-1add-4d21-9379-3cfe8a5f570f",e._sentryDebugIdIdentifier="sentry-dbid-3b23b6e3-1add-4d21-9379-3cfe8a5f570f")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.73afb8d1.js.map
