import{x as t,b as s,eu as o}from"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7b8b6a0b-c795-4d47-a651-be568162f322",e._sentryDebugIdIdentifier="sentry-dbid-7b8b6a0b-c795-4d47-a651-be568162f322")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.cc86e214.js.map
