import{x as o,a,b as i,c,g as p,h as _,_ as d,i as u,T as f,j as l,P as h,C as b,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.df0b7764.js";import{u as k}from"./index.52f87cef.js";import"./pubsub.82647744.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fe749b5b-1fe2-4fe6-9abf-81a5c59be0cc",e._sentryDebugIdIdentifier="sentry-dbid-fe749b5b-1fe2-4fe6-9abf-81a5c59be0cc")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.2b1de031.js"),["assets/Player.2b1de031.js","assets/index.8131d28d.js","assets/outputWidgets.df0b7764.js","assets/outputWidgets.e6401203.css","assets/uuid.29060192.js","assets/broker.83cb95a9.js","assets/index.52f87cef.js","assets/pubsub.82647744.js","assets/executeJs.ce7b3245.js","assets/icons.649962e7.js","assets/CircularLoading.43a277ec.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.756a1cc1.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.cb980244.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.d2e169f5.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.eac698ad.js","assets/broker.1fe265d9.css","assets/DashPlayer.44e6dbdb.js","assets/geometryUtils.a2726904.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.46396f29.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.572b30af.js.map
