import{d as b,ez as g,eA as v,r as k,b as r,c as a,w as s,u as e,f as u,ew as n}from"./outputWidgets.df0b7764.js";import{S as h,L as w}from"./SmartConsole.c7a81284.js";import{a as x}from"./asyncComputed.46396f29.js";import{H as B}from"./hooks.e33124b6.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.3b3cc322.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.45399517.js";import{B as I}from"./BaseLayout.2f5857c5.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.d0981a4e.js";import{c as A}from"./index.ff998eb1.js";import{A as _,T as D}from"./TabPane.54a94f83.js";import"./forms.fe843e69.js";import"./activeRecord.af31c98a.js";import"./pubsub.82647744.js";import"./dashes.27a2359d.js";import"./index.8131d28d.js";import"./jobs.7cde33de.js";import"./workspaces.3593d617.js";import"./url.b34e96a5.js";import"./icons.649962e7.js";import"./Title.d627f1f5.js";import"./index.b2e095c7.js";import"./uuid.29060192.js";import"./ant-design.3dd40e2b.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.2b57bf3c.js";import"./RunButton.vue_vue_type_script_setup_true_lang.4696e650.js";import"./index.993f77ef.js";import"./index.5c49f4fd.js";import"./CollapsePanel.1b17f2cb.js";import"./index.317ac553.js";import"./index.004a66c2.js";import"./index.eb14364d.js";import"./Form.29bcac3f.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="42306dae-7390-4abe-a148-c5b8f5b88ef5",i._sentryDebugIdIdentifier="sentry-dbid-42306dae-7390-4abe-a148-c5b8f5b88ef5")}catch{}})();const le=b({__name:"HookEditor",setup(i){const m=g(),l=v(),f=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),c=w.create();return(R,d)=>(r(),a(I,null,{navbar:s(()=>[e(t)?(r(),a(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:s(()=>[u(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:s(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),a(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(S,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),a(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:s(()=>{var p;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.c4418602.js.map
