import{R as d}from"./Title.d627f1f5.js";import{F as n}from"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="be711f1d-b131-47e0-9e9f-ebed0b25e8fc",e._sentryDebugIdIdentifier="sentry-dbid-be711f1d-b131-47e0-9e9f-ebed0b25e8fc")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.b2e095c7.js.map
