import{cG as d}from"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="bc126fae-bcd9-4168-9d85-e2b19a917238",e._sentryDebugIdIdentifier="sentry-dbid-bc126fae-bcd9-4168-9d85-e2b19a917238")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.4bd19d32.js.map
