import"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="a793b2e0-4e41-4ce0-8f25-adfc1d650595",e._sentryDebugIdIdentifier="sentry-dbid-a793b2e0-4e41-4ce0-8f25-adfc1d650595")}catch{}})();function a(e){return e.charAt(0).toUpperCase()+e.slice(1)}function c(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{a as c,c as n};
//# sourceMappingURL=string.ff9f2867.js.map
