import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.df0b7764.js";import{S as w,L as j}from"./SmartConsole.c7a81284.js";import{a as x}from"./asyncComputed.46396f29.js";import{J as I}from"./jobs.7cde33de.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.3b3cc322.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.45399517.js";import{B as S}from"./BaseLayout.2f5857c5.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.6dd436f1.js";import{c as D}from"./index.ff998eb1.js";import{A as _,T as R}from"./TabPane.54a94f83.js";import"./forms.fe843e69.js";import"./activeRecord.af31c98a.js";import"./pubsub.82647744.js";import"./dashes.27a2359d.js";import"./index.8131d28d.js";import"./hooks.e33124b6.js";import"./workspaces.3593d617.js";import"./url.b34e96a5.js";import"./icons.649962e7.js";import"./Title.d627f1f5.js";import"./index.b2e095c7.js";import"./uuid.29060192.js";import"./ant-design.3dd40e2b.js";import"./RunButton.vue_vue_type_script_setup_true_lang.4696e650.js";import"./index.58a813f4.js";import"./index.eb14364d.js";import"./dayjs.e100b330.js";import"./Form.29bcac3f.js";import"./index.317ac553.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="268753a8-a71f-486f-a462-3124b8e7453c",i._sentryDebugIdIdentifier="sentry-dbid-268753a8-a71f-486f-a462-3124b8e7453c")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),f=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),c=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.cfb88764.js.map
