import{d as c,eA as u,J as b,b as y,c as g,u as _}from"./outputWidgets.df0b7764.js";import{a as w}from"./asyncComputed.46396f29.js";import"./router.7d542f8a.js";import{M as n}from"./member.0a251f56.js";import"./index.be0d60a2.js";import{C as I}from"./CrudView.c17fe492.js";import"./Title.d627f1f5.js";import"./index.8131d28d.js";import"./gateway.315bccd7.js";import"./activeRecord.af31c98a.js";import"./pubsub.82647744.js";import"./icons.649962e7.js";import"./index.0830e379.js";import"./Form.29bcac3f.js";import"./url.b34e96a5.js";import"./index.eb14364d.js";import"./index.b2e095c7.js";import"./index.5c49f4fd.js";import"./index.317ac553.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b4423f14-cf8e-4992-bdff-9036fd53ffff",e._sentryDebugIdIdentifier="sentry-dbid-b4423f14-cf8e-4992-bdff-9036fd53ffff")}catch{}})();const F=c({__name:"Members",setup(e){const r=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),d()},{loading:l,result:f,refetch:d}=w(()=>n.list(r)),p=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=f.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.48433834.js.map
