import{v as s}from"./icons.649962e7.js";import{d as r,a as c,b as i,eu as d,f as _,u as f,aJ as l,x as u}from"./outputWidgets.df0b7764.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ce7aafab-2878-4f91-b994-78e849d47349",e._sentryDebugIdIdentifier="sentry-dbid-ce7aafab-2878-4f91-b994-78e849d47349")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.a8d9ecda.js.map
